@@ -4,8 +4,7 @@
 #' 
 #' @param text.var The text variable. 
 #' @param grouping.var The grouping variables.  Also takes a single 
-#' grouping variable or a list 
-#' of 1 or more grouping variables.
+#' grouping variable or a list of 1 or more grouping variables.
 #' @param inds A list of integer indices to print context for.
 #' @param n.before The number of rows before the indexed occurrence.
 #' @param tot logical.  If \code{TRUE} condenses sub-units (e.g., sentences) 
@@ -174,7 +173,7 @@ print.qdap_context <- function(x, file = NULL, pretty = TRUE, width = 70,
     }
     if(is.null(FE)) {
         if(pretty) {
-            message(out)
+            cat(out)
         } else {
             print(out, quote = FALSE)
         }
